Installation — Geraldo Reports Documentation v0.3.4-final documentation

### Navigation

- index
- Geraldo Reports Documentation v0.3.4-final documentation »

# Installation

Geraldo is still not available as installer or system package. So, you have two ways to install it:

## Option 1. Get the latest official version

1. Get the latest tarball available from:

   > https://sourceforge.net/project/showfiles.php?group_id=251460&package_id=307400

2. Then you can do the following steps to install it:

Linux

    tar xvfz geraldo-latest.tar.gz
    cd geraldo
    sudo python setup.py install

This will copy Geraldo’s packages inside Python packages path.

Windows

If you are using Windows, Geraldo is fully compatible. You just have to use a tarball uncompress tool, like 7-Zip you can download from:

> http://www.7-zip.org/download.html

Once you have a tool to uncompress tarball files, you have to uncompress it, open a MS-DOS Prompty window in the folder you uncompress into and run the following command:

    python setup.py install

## Option 2. Get the latest development version

Our version control is centralized on GitHub Social repository, in the following URL:

    http://github.com/marinho/geraldo

To get the latest development version from repository server, you will need for Git version control system. Then you can run the following command in Shell or MS-DOS Prompty window:

    git clone git://github.com/marinho/geraldo.git

A folder named geraldo will be in your current path with all Geraldo files inside.

Then you can go ahead and use the same commands from Option 1 to install in your system.

## Dependencies

ReportLab

This is required, there is no chance you use Geraldo with no ReportLab installed.

Get it from the following URL:

> http://www.reportlab.org/

The tested version is 2.1.

Python Imaging Library

Geraldo depends on PIL for works with Images manipulation on the canvas. If you aren’t going to use them, you can live without PIL.

To get PIL you can go to following URL:

> http://www.pythonware.com/products/pil/

### Navigation

- index
- Geraldo Reports Documentation v0.3.4-final documentation »